@@ -36,7 +36,7 @@ OpenURLAction = model("OpenURLAction", "url")
 ShareAction = model("ShareAction", "")
 SendImageAction = model("SendImageAction", "image_url alt")
 SendTextAction = model("SendTextAction", "alternatives text")
-SendJSEventAction = model("SendJSEventAction", "event")
+SendJSEventAction = model("SendJSEventAction", "event payload")
 SendEmailAction = model("SendEmailAction", "from_name from_email content subject recipient")
 WaitAction = model("WaitAction", "duration")
 PauseBotAction = model("PauseBotAction", "")
