@@ -12,7 +12,7 @@ def interlocutor():
         first_name="tintin",
         last_name=None,
         phone_number="0645592034",
-        custom_attributes={"age": "21"}
+        custom_attributes={"age": "21"},
     )
 
 
@@ -20,15 +20,25 @@ def interlocutor():
 def data():
     return {
         "id": "123",
-        "location": {
-            "lat": 1,
-            "long": 2
-        },
+        "location": {"lat": 1, "long": 2},
         "email": "tintin@moulinsart.fr",
         "firstName": "tintin",
         "lastName": None,
         "phoneNumber": "0645592034",
-        "customAttributes": {"age": "21"}
+        "customAttributes": {"age": "21"},
+    }
+
+
+@pytest.fixture
+def malicious_data():
+    return {
+        "id": "123",
+        "location": {"lat": 1, "long": 2},
+        "email": "tintin@moulinsart.fr",
+        "firstName": "<script>void();</script>tintin",
+        "lastName": None,
+        "phoneNumber": "0645592034",
+        "customAttributes": {"age": "21"},
     }
 
 
@@ -50,3 +60,9 @@ class TestLoad(object):
         assert result.last_name is None
         assert result.custom_attributes == {"age": "21"}
         assert result.phone_number == "0645592034"
+
+    def test_returns_an_object_malicious(self, malicious_data):
+        result = MAPPER.load(malicious_data, "webhook_interlocutor")
+        assert isinstance(result, Interlocutor)
+        assert result.email == "tintin@moulinsart.fr"
+        assert result.first_name == "&lt;script&gt;void();&lt;/script&gt;tintin"
